#!/bin/bash

mkdir build && cd build

cmake ${CMAKE_ARGS} -LAH \
  -DCMAKE_PREFIX_PATH="$PREFIX" \
  -DCMAKE_FIND_FRAMEWORK=LAST \
  -DCMAKE_INSTALL_PREFIX="$PREFIX" \
  -DCMAKE_INSTALL_RPATH="${PREFIX}/lib" -DCMAKE_BUILD_WITH_INSTALL_RPATH=ON -DCMAKE_MACOSX_RPATH=ON \
  -DCMAKE_INSTALL_LIBDIR=lib \
  -DCMAKE_BUILD_TYPE="Release"  \
  -DBUILD_SHARED_LIBS=ON \
  -DDLIB_LINK_WITH_SQLITE3=OFF \
  -Dnsllib=nsllib-NOTFOUND \
  ..
make install -j$CPU_COUNT
